@@ -4,7 +4,6 @@ import pkg_resources
 import re
 import sys
 import tempfile
-import unittest
 import warnings
 
 if sys.hexversion < 0x03000000:
@@ -12,6 +11,11 @@ if sys.hexversion < 0x03000000:
 else:
     from io import StringIO
 
+if sys.hexversion < 0x02070000:
+    import unittest2 as unittest
+else:
+    import unittest
+
 import glymur
 
 
